# Conditional for release and snapshot builds. Uncomment for release-builds.
%global rel_build 1

# This is needed, because src-url contains branched part of versioning-scheme.
%global branch 1.16

# Settings used for build from snapshots.
%{!?rel_build:%global commit 83fe1f587f5c6328b10a899a880275d79bf88921}
%{!?rel_build:%global commit_date 20141215}
%{!?rel_build:%global shortcommit %(c=%{commit};echo ${c:0:7})}
%{!?rel_build:%global git_ver git%{commit_date}-%{shortcommit}}
%{!?rel_build:%global git_rel .git%{commit_date}.%{shortcommit}}
%{!?rel_build:%global git_tar %{name}-%{version}-%{git_ver}.tar.xz}

Name:           mate-settings-daemon
Version:        %{branch}.2
%if 0%{?rel_build}
Release:        1%{?dist}
%else
Release:        0.1%{?git_rel}%{?dist}
%endif
Summary:        MATE Desktop settings daemon
License:        GPLv2+
URL:            http://mate-desktop.org

# for downloading the tarball use 'spectool -g -R mate-settings-daemon.spec'
# Source for release-builds.
%{?rel_build:Source0:     http://pub.mate-desktop.org/releases/%{branch}/%{name}-%{version}.tar.xz}
# Source for snapshot-builds.
%{!?rel_build:Source0:    http://git.mate-desktop.org/%{name}/snapshot/%{name}-%{commit}.tar.xz#/%{git_tar}}

# fix rhbz (#1140329)
Patch0:         mate-settings-daemon_fix-xrdb-plugin-for-rhel.patch

BuildRequires:  dbus-glib-devel
BuildRequires:  dconf-devel
BuildRequires:  desktop-file-utils
BuildRequires:  gtk2-devel
BuildRequires:  libcanberra-devel
BuildRequires:  libmatekbd-devel
BuildRequires:  libmatemixer-devel
BuildRequires:  libnotify-devel
BuildRequires:  libSM-devel
BuildRequires:  libXxf86misc-devel
BuildRequires:  mate-common
BuildRequires:  mate-desktop-devel
BuildRequires:  mate-polkit-devel
BuildRequires:  nss-devel
BuildRequires:  pulseaudio-libs-devel

Requires:       libmatekbd%{?_isa} >= 0:1.6.1-1
# needed for xrandr capplet
Requires:       mate-control-center-filesystem
# needed for xrdb fix
Requires:       cpp

%ifnarch s390 s390x
# to be sure that mouse and touchpad settings are working with correct drivers
%if 0%{?fedora}
Requires: xorg-x11-drv-synaptics
Requires: xorg-x11-drv-evdev
%endif
%endif

%description
This package contains the daemon which is responsible for setting the
various parameters of a MATE session and the applications that run
under it.

%package devel
Summary:        Development files for mate-settings-daemon
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains the daemon which is responsible for setting the
various parameters of a MATE session and the applications that run
under it.

%prep
%setup -q

%patch0 -p1 -b .xrdb

%if 0%{?rel_build}
#NOCONFIGURE=1 ./autogen.sh
%else # 0%{?rel_build}
# for snapshots
# needed for git snapshots
NOCONFIGURE=1 ./autogen.sh
%endif # 0%{?rel_build}

%build
%configure                             \
   --enable-pulse                      \
   --disable-static                    \
   --disable-schemas-compile           \
   --enable-polkit                     \
   --with-x                            \
   --with-nssdb                        \
   --with-gtk=2.0

make %{?_smp_mflags} V=1

%install
%{make_install}

find %{buildroot} -name '*.la' -exec rm -rf {} ';'

desktop-file-validate %{buildroot}%{_sysconfdir}/xdg/autostart/mate-settings-daemon.desktop

%find_lang %{name} --with-gnome --all-name

%post
/sbin/ldconfig
/bin/touch --no-create %{_datadir}/icons/mate &> /dev/null || :
/bin/touch --no-create %{_datadir}/hicolor/mate &> /dev/null || :

%postun
/sbin/ldconfig
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/mate &> /dev/null || :
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/mate &> /dev/null || :
    /usr/bin/gtk-update-icon-cache %{_datadir}/hicolor/mate &> /dev/null || :
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi
%if 0%{?fedora}
/usr/bin/rm -f %{_sysconfdir}/X11/xorg.conf.d/99-synaptics-mate.conf
/usr/bin/rm -f %{_sysconfdir}/X11/xorg.conf.d/99-mate-evdev.conf
%endif

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/mate &> /dev/null || :
/usr/bin/gtk-update-icon-cache %{_datadir}/hicolor/mate &> /dev/null || :
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
%if 0%{?fedora}
mkdir -p %{_sysconfdir}/X11/xorg.conf.d/
/usr/bin/ln -sf %{_datadir}/X11/xorg.conf.d/50-synaptics.conf %{_sysconfdir}/X11/xorg.conf.d/99-synaptics-mate.conf &> /dev/null || :
/usr/bin/ln -sf %{_datadir}/X11/xorg.conf.d/10-evdev.conf %{_sysconfdir}/X11/xorg.conf.d/99-mate-evdev.conf &> /dev/null || :
%endif


%files -f %{name}.lang
%doc AUTHORS COPYING README
%dir %{_sysconfdir}/mate-settings-daemon
%dir %{_sysconfdir}/mate-settings-daemon/xrandr
%config %{_sysconfdir}/dbus-1/system.d/org.mate.SettingsDaemon.DateTimeMechanism.conf
%{_sysconfdir}/xdg/autostart/mate-settings-daemon.desktop
%{_sysconfdir}/xrdb/
%if 0%{?fedora}
%ghost %{_sysconfdir}/X11/xorg.conf.d/99-synaptics-mate.conf
%ghost %{_sysconfdir}/X11/xorg.conf.d/99-mate-evdev.conf
%endif
%{_libdir}/mate-settings-daemon
%{_libexecdir}/mate-settings-daemon
%{_libexecdir}/msd-datetime-mechanism
%{_libexecdir}/msd-locate-pointer
%{_datadir}/mate-control-center/keybindings/50-accessibility.xml
%{_datadir}/dbus-1/services/org.mate.SettingsDaemon.service
%{_datadir}/dbus-1/system-services/org.mate.SettingsDaemon.DateTimeMechanism.service
%{_datadir}/icons/mate/*/*/*
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mate-settings-daemon
%{_datadir}/glib-2.0/schemas/org.mate.*.xml
%{_datadir}/polkit-1/actions/org.mate.settingsdaemon.datetimemechanism.policy
%{_mandir}/man1/*

%files devel
%{_includedir}/mate-settings-daemon
%{_libdir}/pkgconfig/mate-settings-daemon.pc


%changelog
* Sun Mar 26 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.2-1
- update to 1.16.2 release
- fixes rhbz (#1420709, #1383272)

* Sun Feb 05 2017 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.1-1
- update to 1.16.1 release

* Sat Dec 10 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.0-2
- add priority symlinks for synaptics and evdev driver

* Sun Oct 02 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.16.0-1
- update to 1.16.0 release

* Fri Aug 12 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.1-1
- update to 1.14.1 release

* Sun Jun 12 2016 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.14.0-1
- update to 1.14.0 release

* Sun Dec 27 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.12.1-1
- update to 1.12.1 release

* Wed Nov 25 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-2
- rebuild for 7.2 upgrade

* Mon Aug 31 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.2-1
- update to 1.10.2 release
- remove upstreamed patches
- add upstream touchpad improvement

* Sat Aug 08 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-2
- fix non working audio keys

* Sat Jul 18 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.10.1-1
- update to 1.10.1 release
- remove upstreamed patches

* Wed Mar 11 2015 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.3.1
- update to 1.8.3 release
- fix rhbz (#1157698)
- add mate-settings-daemon_a11y-keyboard-crash.patch

* Wed Nov 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.2-3
- add missing require to cpp

* Wed Nov 12 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.2-2
- fix xrdb plugin (#1140329)

* Thu Oct 02 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.2-1
- update to 1.8.2 release

* Tue Aug 19 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.8.1-1
- update to 1.8.1

* Tue Apr 01 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.8.0-2
- Comment out hard requires on mate-control-center-filesystem due to build failures.
- Bump release and rebuild.

* Wed Mar 05 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.8.0-1
- Update to 1.8.0

* Tue Feb 18 2014 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.7.90-1
- update to 1.7.90
- use --with-gnome --all-name for find locale
- use modern 'make install' macro
- add man dir

* Sun Feb 09 2014 Dan Mashal <dan.mashal@fedoraproject.org> - 1.7.1-1
- Update to 1.7.1

* Thu Dec 05 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.7.0-1
- Update to 1.7.0

* Thu Oct 03 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.2-0.3.gitd2d3aa7
- enable pulsaudio support

* Tue Oct 01 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.2-0.2.gitd2d3aa7
- add misssing directory for xrandr-capplet function 'system-wide installation'
- add runtime requires mate-control-center-filesystem for xrandr-capplet

* Mon Sep 23 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.2-0.1.gitd2d3aa7
- update to latest snapshot
- fix https://github.com/mate-desktop/mate-settings-daemon/issues/32
- remove runtime require mate-icon-theme, no need of it
- remove %%config from desktop file
- remove needless find '*.a'
- switch to pulseaudio, fix rhbz (#1008011)
- cleanup BRs

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 28 2013 Wolfgang Ulbrich <chat-to-me@raveit.de> - 1.6.1.2
- remove BR gsettings-desktop-schemas-devel
- remove needless gsettings convert file
- clean up BR's
- add versioned runtime require libmatekbd

* Mon Jun 24 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.6.1-1
- Update to latest upstream release.

* Sat Jun 22 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.6.0-3
- Update libnotify.patch with latest upstream commits

* Tue Jun 11 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.6.0-2
- Add libnotify patch

* Wed Apr 03 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.6.0-1
- Update to latest 1.6.0 stable release.

* Tue Mar 26 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.7-1
- Update to latest upstream release

* Fri Feb 08 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.5-1
-Update to latest upstream release
-Convert back to old BR style
-Own dirs we are supposed to own

* Tue Jan 15 2013 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.4-3
- Fix icon scriptlets

* Fri Dec 21 2012 Nelson Marques <nmarques@fedoraproject.org> - 1.5.4-2
- Fix broken gstreamer support:
  + add gstreamer BuildRequires
  + disable pulse so we build with gstreamer support
- Add '--disable-static' to %%configure and remove find entries
- Improve description, overall readability, order dependencies and
  minor improvements

* Mon Dec 03 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.4-1
- Latest upstream release

* Fri Nov 23 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.3-5
- Remove archlinux configure.ac bits.
- REALLY fix CVE-2012-5560

* Fri Nov 23 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.3-4
- stop generating version specific libdirs for plugins and fix CVE-2012-5560

* Thu Nov 22 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.3-3
- fix build failures

* Thu Nov 22 2012 Dan Mashal <dan.mashal@fedoraproject.org> - 1.5.3-2
- drop mate-corba from br as it is deprecated

* Mon Oct 29 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.5.3-1
- update to 1.5.3 release

* Mon Oct 29 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.5.0-1
- update to 1.5.0 release
- add schema scriptlets and remove mateconf scriptlets
- add requires gsettings-desktop-schemas
- add build requires gsettings-desktop-schemas-devel
- change build requires style

* Wed Oct 10 2012 Rex Dieter <rdieter@fedoraproject.org> 1.4.0-6
- fix icon scriptlets

* Fri Sep 28 2012 Rex Dieter <rdieter@fedoraproject.org> - 1.4.0-5
- remove local quirks not needed for fedora buildsys
- simplify %%files, fix some dir-ownership
- cosmetics: move scriptlets to be next to %%files

* Tue Sep 25 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-4
- Own mate-settings-daemon directory, update build requires and configure flags

* Tue Sep 25 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-3
- Fix mateconf scritplets, switch back to upstream source.

* Sat Sep 15 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-2
- Move shared libs to main package and update buildrequires to add libSM-devel add mateconf scriptlets

* Sat Sep 01 2012 Dan Mashal <dan.mashal@fedoraproject.org> 1.4.0-1
- Initial build
